# Display Group

Display group commands are used to select a subset of the entities displayed in the viewport.

## Create display groups

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupSession.DisplayGroupSession
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.DisplayGroup
        :recursive:
        :exclude: DisplayGroupSession

    .. placeholder for empty members
```
